package Source::Repository::Mass::RepoCompare;

use strict;
use warnings;
use Carp;

use Source::Repository::Mass;
our @ISA = qw/Source::Repository::Mass/;
push @Source::Repository::Mass::EXT_LONGOPT_CLASSES, __PACKAGE__;
$Source::Repository::Mass::strategy = 'newer';

our $VERSION=0.002;
our $verbose=0;
our $opt_format='%{ORIGINNAME}\t%{ORIGINFILE}\t%{DESTFILE}\n';
my $updatelist5_format='%{DESTNAME}\t%{ORIGINNAME}\t%{DESTVERSION}\t%{ORIGINVERSION}\t%{ORIGINURL}\n';

our @LONGOPT = (
	"qf|queryformat|format=s"	=> \$opt_format,
	"updatelist5|update5"	=> sub {$opt_format=$updatelist5_format},
    );
sub print_longopt {
    print "CompareRepository Outout options:
	--queryformat    output format. default is $opt_format
	--updatelist5    output in updatelist5 format
";
}

sub process_pair {
    my ($self,$rpmmap, $transaction_name, $transaction_count)=@_;
    my $out=$opt_format;
    $out=~s/\%\{(ORIGIN|DEST)(NAME|FILE|URL|VERSION|RELEASE|EPOCH)\}/&__getval($rpmmap,$1,$2)/eg;
    $out=~s/\\t/\t/g;
    $out=~s/\\n/\n/g;
    print $out;
    #print "process_pair:", $rpmmap->originname, "\n";
}

sub __getval {
    my ($rpmmap,$repo,$val)=@_;
    return $rpmmap->originname if $repo eq 'ORIGIN' and $val eq 'NAME';
    return $rpmmap->destname if $repo eq 'DEST' and $val eq 'NAME';
    my $pkg=$rpmmap->origin;
    $pkg=$rpmmap->dest if $repo eq 'DEST';
    return 'undef' unless $pkg;
    return $pkg->file if $val eq 'FILE';
    return $pkg->url if $val eq 'URL';
    return $pkg->version if $val eq 'VERSION';
    return $pkg->release if $val eq 'RELEASE';
    return $pkg->epoch if $val eq 'EPOCH';
    #print "Oops: $repo, $val\n";
    return '%{'.$repo.$val.'}';
}

1;
