# ALT Linux files/list/{bin,src}.list format
# skip if name is mentioned there
package Source::Repository::Mass::SkipName::AltFilesList;

use strict;
use warnings;
#use Carp;

use Source::Repository::Mass::SkipName;
our @ISA=qw/Source::Repository::Mass::SkipName/;
push @Source::Repository::Mass::NameFilter::NAME_SKIP_CLASSES, __PACKAGE__;

our $VERSION=0.002;

our $verbose=0;
our @opt_origin_listfiles;
our @opt_dest_listfiles;
my $opt_exclude_mode=0;
my $opt_disabled=1;
my (%ORIGINDB,%DESTDB);

our @LONGOPT = (
    'altlistfile-exclude!'	=> \$opt_exclude_mode,
    "origin-altlistfile=s"	=> \@opt_origin_listfiles,
    "dest-altlistfile=s"	=> \@opt_dest_listfiles,
    );

sub print_longopt {
    print "  Limit mass operation by intermediate repo options:
	--origin-altlistfile /file1:...:/fileN ALT Linux files/list/{bin,src}.list files to load
	--dest-altlistfile /file1:...:/fileN ALT Linux files/list/{bin,src}.list files to load
";
}

sub process_options {
    my @origin_listfiles=map {split /:/} @opt_origin_listfiles;
    my @dest_listfiles=map {split /:/} @opt_dest_listfiles;
    unless (@origin_listfiles or @dest_listfiles) {
	# explicitly remove itself from the list of filters
	@Source::Repository::Mass::NameFilter::NAME_SKIP_CLASSES=grep {$_ ne __PACKAGE__}
	@Source::Repository::Mass::NameFilter::NAME_SKIP_CLASSES;
	return;
    }
    # only enable itself when options are presented!
    # or filter will just reject everything
    $opt_disabled=0;
    &__load_db(\%ORIGINDB,\@origin_listfiles);
    &__load_db(\%DESTDB,\@dest_listfiles);
}

sub __load_db {
    my ($list_db, $listfiles)=@_;
    local $_;
    foreach my $listfile (@$listfiles) {
	open (my $fn, '<', $listfile) or die "Can't open ALT Linux format list file $listfile: $!";
	while (<$fn>) {
	    chomp;
	    my ($name)=split(/\s+/,$_);
	    $list_db->{$name}=1;
	    print STDERR "DEBUG: Mass::SkipPkg::AltFilesList: loaded $name\n" if $verbose && $verbose>3;
	}
	close ($fn);
    }
}

sub namefilter {
    my ($matcher,$originname,$destname)=@_;
    if ($verbose && $verbose>1) {
	print STDERR "DEBUG: SkipName::AltFilesList: filtering ($originname,$destname)\n" if $verbose>2;
	print STDERR "DEBUG: SkipName::AltFilesList: origin found $originname\n" if $ORIGINDB{$originname};
	print STDERR "DEBUG: SkipName::AltFilesList: dest found $destname\n" if $DESTDB{$destname};
    }
    return 0 if $opt_disabled;
    if ($opt_exclude_mode) {
	# exclude listed
	if ($ORIGINDB{$originname} or $DESTDB{$destname}) {
	    print STDERR "DEBUG: SkipName::AltFilesList: rejected ($originname,$destname)\n" if $verbose;
	    return 1;
	}
	return;
    } else {
	# exclude not listed
	return 0 if $ORIGINDB{$originname} or $DESTDB{$destname};
	print STDERR "DEBUG: SkipName::AltFilesList: rejected ($originname,$destname)\n" if $verbose;
	return 1;
    }
}

1;
