package Source::Repository::Mass::Transform::Embedded;

use strict;
use warnings;
use Source::Repository::RPM;
use Source::Repository::Mass::Transform;
use RPM::Source::TransformContainer 0.004;
use RPM::Source::Transformation::CoreTransformationSet;
use RPM::Source::Transformation::RPMEditorProvider;
use RPM::Source::Transformation::PkgWriter;

our @ISA = qw(Source::Repository::Mass);

$RPM::Source::Transformation::PkgWriter::outputdir=$Source::Repository::Mass::Transform::DEFAULT_OUTDIR;

push @Source::Repository::Mass::EXT_LONGOPT_CLASSES, 'RPM::Source::TransformContainer';

our $verbose=1;

sub cli_container_ref {
    return ['Source::Repository::Mass'];
}

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    RPM::Source::TransformContainer->init_transformations();
    return $self;
};

sub process_pair {
    my ($self,$pkgpair,$transaction_name,$transaction_count)=@_;
    my ($originname, $destname)=($pkgpair->originname,$pkgpair->destname);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    if (not $origin) {
	print STDERR "ERROR: origin file for $originname not found.\n";
	return;
    }
    my $converter_opt=RPM::Source::TransformContainer->mk_opt();
    my $proposed_rename=$destname if $destname ne $originname and not $Source::Repository::Mass::Transform::suppress_rename;
    if ($proposed_rename) {
	my $cur_rename=$converter_opt->{-rename};
	if(defined $cur_rename) {
	    print STDERR "info: not renaming to ",$proposed_rename,': already renamed to ',$cur_rename,"\n";
	} else {
	    $converter_opt->{-rename}=$proposed_rename;
	}
    }
    $converter_opt->{-transaction_output_subdir} = &Source::Repository::Mass::Transform::__transaction_output_subdir($transaction_name,$transaction_count) if defined($transaction_name);
    my ($spec,$parent)=$self->get_spec_parent($pkgpair,$converter_opt);
    if ($Source::Shared::verbose or $verbose) {
	print STDERR "info: origin: $spec->{SOURCERPM}\n" if ($spec and $spec->{SOURCERPM});
	print STDERR "info: parent: $parent->{SOURCERPM}\n" if $parent and $parent->{SOURCERPM};
    }

    RPM::Source::TransformContainer->transform_once($spec,$parent,$converter_opt);

    print STDERR "---*---\n" if $verbose;
}

sub get_spec_parent {
    my ($self,$pkgpair,$converter_opt)=@_;
    my ($spec,$parent);
    my ($origin, $dest)=($pkgpair->origin,$pkgpair->dest);
    $spec=$RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2spec(
	    Source::Repository::RPM->pkg4rpmeditor($origin)
	) if $origin;
    $parent=$RPM::Source::TransformContainer::RPMEditorProvider->rpmeditoropts2parent(
	$dest ? Source::Repository::RPM->pkg4rpmeditor($dest): undef
	);
    return ($spec,$parent);
}

1;
